@@ -18,18 +18,20 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
+#include "ksudoku_logging.h"
 #include "gamevariants.h"
 #include "ksudokugame.h"
 #include "serializer.h"
 
-#include <QtDebug>
-#include <KMessageBox>
-#include <KLocale>
-#include <QPainter>
-#include <KIconLoader>
+#include <QDebug>
 #include <QEvent>
+#include <QIcon>
+#include <QPainter>
+
+#include <KLocalizedString>
+#include <KMessageBox>
+
 
-#include "gamevariants.moc"
 
 #include "puzzle.h"
 
@@ -183,13 +185,13 @@ void GameVariantDelegate::paint(QPainter* painter, const QStyleOptionViewItem& o
 
 	// Show icon
 
-	QPixmap iconPixmap = KIcon(icon(index), KIconLoader::global()).pixmap(m_iconWidth, m_iconHeight);
+	QPixmap iconPixmap = QIcon::fromTheme(icon(index)).pixmap(m_iconWidth, m_iconHeight);
 	painter->drawPixmap(contentRect.left(), (contentRect.height() - iconPixmap.height()) / 2 + contentRect.top(), iconPixmap);
 	contentRect.adjust(iconPixmap.width() + m_separatorPixels*2, 0, 0, 0);
 
 // 	// Show configuration icon
 // 	if(configurable(index)) {
-// 		QPixmap configPixmap = KIcon( QLatin1String( "configure" ), KIconLoader::global()).pixmap(32, 32);
+// 		QPixmap configPixmap = QIcon::fromTheme( QLatin1String( "configure" ) ).pixmap(32, 32);
 // 		painter->drawPixmap(contentRect.right() - configPixmap.width(), (contentRect.height() - configPixmap.height()) / 2 + contentRect.top(), configPixmap);
 // 		contentRect.adjust(0, 0, -(configPixmap.width() + separatorPixels), 0);
 // 	}
@@ -303,7 +305,7 @@ Game SudokuGame::createGame(int difficulty, int symmetry) {
 }
 
 KsView* SudokuGame::createView(const Game& /*game*/) const {
-	qDebug() << "KsView* ksudoku::SudokuGame::createView()";
+	qCDebug(KSudokuLog) << "KsView* ksudoku::SudokuGame::createView()";
 	return 0;
 }
 
@@ -355,7 +357,7 @@ Game RoxdokuGame::createGame(int difficulty, int symmetry) {
 }
 
 KsView* RoxdokuGame::createView(const Game& /*game*/) const {
-	qDebug() << "KsView* ksudoku::RoxdokuGame::createView()";
+	qCDebug(KSudokuLog) << "KsView* ksudoku::RoxdokuGame::createView()";
 	return 0;
 }
 
@@ -363,7 +365,7 @@ KsView* RoxdokuGame::createView(const Game& /*game*/) const {
 // class CustomGame
 ///////////////////////////////////////////////////////////////////////////////
 
-CustomGame::CustomGame(const QString& name, const KUrl& url,
+CustomGame::CustomGame(const QString& name, const QUrl& url,
                        GameVariantCollection* collection)
 	: GameVariant(name, collection), m_url(url), m_graph(0)
 {
@@ -403,7 +405,7 @@ Game CustomGame::createGame(int difficulty, int symmetry) {
 }
 
 KsView* CustomGame::createView(const Game& /*game*/) const {
-	qDebug() << "KsView* ksudoku::CustomGame::createView()";
+	qCDebug(KSudokuLog) << "KsView* ksudoku::CustomGame::createView()";
 	return 0;
 }
 
@@ -415,7 +417,8 @@ bool CustomGame::createSKGraphObject()
 	    m_graph = 0;	// Killer Sudoku game (re-inits cages and size).
 	}
 	if (m_graph == 0) {
-	    m_graph = ksudoku::Serializer::loadCustomShape(m_url, 0, 0);
+		QString errorMsg;
+		m_graph = ksudoku::Serializer::loadCustomShape(m_url, 0, errorMsg);
 	}
 	return (m_graph != 0);	// True if the shapes/*.xml file loaded OK.
 }
