@@ -2,8 +2,7 @@
  *   Copyright 2005-2007 Francesco Rossi <redsh@email.it>                  *
  *   Copyright 2006-2007 Mick Kappenburg <ksudoku@kappendburg.net>         *
  *   Copyright 2006-2008 Johannes Bergmeier <johannes.bergmeier@gmx.net>   *
- *   Copyright 2012      Ian Wadham <iandw.au@gmail.com>                   *
- *   Copyright 2015      Ian Wadham <iandw.au@gmail.com>                   *
+ *   Copyright 2012,2015 Ian Wadham <iandw.au@gmail.com>                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,36 +20,43 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
+#include "ksudoku_logging.h"
 #include "globals.h"
 #include "ksudoku.h"
 
+#include <QAction>
+#include <QComboBox>
+#include <QDir>
+#include <QDebug>
 #include <QDragEnterEvent>
 #include <QDropEvent>
-#include <ksavefile.h>
-
-#include <QHBoxLayout>
+#include <QFileDialog>
+#include <QFileInfo>
+#include <QMimeData>
 #include <QLabel>
-#include <QComboBox>
+#include <QHBoxLayout>
+#include <QKeySequence>
+#include <QPrinter>
+#include <QPrintDialog>
+#include <QStandardPaths>
+#include <QStatusBar>
+#include <QTemporaryFile>
+#include <QUrl>
 
-#include <KLocale>
 #include <KActionCollection>
-#include <KStandardAction>
-#include <KAction>
 #include <KConfigDialog>
+#include <KIO/Job>
+#include <KJobWidgets>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KSharedConfig>
+#include <KStandardAction>
+#include <KStandardGameAction>
+#include <KTar>
 
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgamethemeselector.h>
 
-#include <KCmdLineArgs>
-#include <KAboutData>
-
-#include <kmessagebox.h>
-#include <klocale.h>
-#include <kstatusbar.h>
-#include <kio/netaccess.h>
-#include <kfiledialog.h>
-#include <krun.h>
-
 #include "ksview.h"
 #include "gameactions.h"
 #include "renderer.h"
@@ -61,11 +67,6 @@
 
 #include "puzzleprinter.h"
 
-#include <ktar.h>
-#include <kstandarddirs.h>
-#include <kio/job.h>
-#include <kstandardgameaction.h>
-
 #include "gamevariants.h"
 #include "welcomescreen.h"
 #include "valuelistwidget.h"
@@ -149,16 +150,13 @@ KSudoku::KSudoku()
 
 	m_welcomeScreen = new WelcomeScreen(wrapper, m_gameVariants);
 	wrapper->layout()->addWidget(m_welcomeScreen);
-	connect(m_welcomeScreen, SIGNAL(newGameStarted(const ::ksudoku::Game&,GameVariant*)), this, SLOT(startGame(const ::ksudoku::Game&)));
+	connect(m_welcomeScreen, &ksudoku::WelcomeScreen::newGameStarted, this, &KSudoku::startGame);
 
 	setupStatusBar(m_welcomeScreen->difficulty(),
 		       m_welcomeScreen->symmetry());
 
 	showWelcomeScreen();
 
-	// Register the gamevariants resource
-	KGlobal::dirs()->addResourceType ("gamevariant", "data", KCmdLineArgs::aboutData()->appName());
-
 	updateShapesList();
 
 // 	QTimer *timer = new QTimer( this );
@@ -187,26 +185,33 @@ void KSudoku::updateShapesList()
 	variant->setIcon("ksudoku-roxdoku_3x3x3");
 #endif
 
-    QStringList filepaths = KGlobal::dirs()->findAllResources("gamevariant", "*.desktop", KStandardDirs::NoDuplicates); // Find files.
+	const QStringList gamevariantdirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "ksudoku", QStandardPaths::LocateDirectory);
+
+	QFileInfoList filepaths;
+	for (const QString& gamevariantdir : gamevariantdirs) {
+		const auto fileNames = QDir(gamevariantdir).entryInfoList(QStringList() << QStringLiteral("*.desktop"), QDir::Files | QDir::Readable | QDir::NoDotAndDotDot);
+		filepaths.append(fileNames);
+	}
 
 	QString variantName;
 	QString variantDescr;
 	QString variantDataPath;
 	QString variantIcon;
 
-	foreach(const QString &filepath, filepaths) {
-		KConfig variantConfig(filepath, KConfig::SimpleConfig);
+	for (const QFileInfo &configFileInfo : qAsConst(filepaths)) {
+		const QDir variantDir = configFileInfo.dir();
+		KConfig variantConfig(configFileInfo.filePath(), KConfig::SimpleConfig);
 		KConfigGroup group = variantConfig.group ("KSudokuVariant");
 
 		variantName = group.readEntry("Name", i18n("Missing Variant Name")); // Translated.
 		variantDescr = group.readEntry("Description", ""); // Translated.
 		variantIcon = group.readEntry("Icon", "ksudoku-ksudoku_9x9");
-		variantDataPath = group.readEntry("FileName", "");
-		if(variantDataPath == "") continue;
+		const QString variantDataFile = group.readEntry("FileName", "");
+		if(variantDataFile == "") continue;
 
-		variantDataPath = filepath.left(filepath.lastIndexOf("/")+1) + variantDataPath;
+		variantDataPath = variantDir.filePath(variantDataFile);
 
-		variant = new CustomGame(variantName, variantDataPath, m_gameVariants);
+		variant = new CustomGame(variantName, QUrl::fromLocalFile(variantDataPath), m_gameVariants);
 		variant->setDescription(variantDescr);
 		variant->setIcon(variantIcon);
 	}
@@ -238,8 +243,8 @@ void KSudoku::startGame(const Game& game) {
 	view->setValueListWidget(m_valueListWidget);
 	view->createView();
 
-	connect(view, SIGNAL(valueSelected(int)), m_valueListWidget, SLOT(selectValue(int)));
-	connect(m_valueListWidget, SIGNAL(valueSelected(int)), view, SLOT(selectValue(int)));
+	connect(view, &KsView::valueSelected, m_valueListWidget, &ksudoku::ValueListWidget::selectValue);
+	connect(m_valueListWidget, &ksudoku::ValueListWidget::valueSelected, view, &KsView::selectValue);
 // 	connect(view, SIGNAL(valueSelected(int)), SLOT(updateStatusBar()));
 
 	QWidget* widget = view->widget();
@@ -355,9 +360,9 @@ void KSudoku::endCurrentGame() {
 
 }
 
-void KSudoku::loadGame(const KUrl& Url) {
+void KSudoku::loadGame(const QUrl& Url) {
 	QString errorMsg;
-	Game game = ksudoku::Serializer::load(Url, this, &errorMsg);
+	const Game game = ksudoku::Serializer::load(Url, this, errorMsg);
 	if(!game.isValid()) {
 		KMessageBox::information(this, errorMsg);
 		return;
@@ -372,11 +377,6 @@ void KSudoku::showWelcomeScreen() {
 	m_welcomeScreen->show();
 }
 
-void KSudoku::homepage()
-{
-	KRun::runUrl (KUrl("http://ksudoku.sourceforge.net/"), "text/html", this);
-}
-
 void KSudoku::giveHint()
 {
 	Game game = currentGame();
@@ -452,7 +452,7 @@ void KSudoku::setupActions()
 	m_gameActions = new ksudoku::GameActions(actionCollection());
 	m_gameActions->init();
 
-	KShortcut shortcut;
+	QKeySequence shortcut;
 
 	setAcceptDrops(true);
 
@@ -467,7 +467,7 @@ void KSudoku::setupActions()
 
 	KStandardAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
 	// Settings: enable messages that the user marked "Do not show again".
-	KAction* enableMessagesAct = new KAction(i18n("Enable all messages"),0);
+	QAction* enableMessagesAct = new QAction(i18n("Enable all messages"),0);
 	actionCollection()->addAction("enable_messages", enableMessagesAct);
 	connect(enableMessagesAct, SIGNAL(triggered()), SLOT(enableMessages()));
 
@@ -475,28 +475,19 @@ void KSudoku::setupActions()
 	KStandardGameAction::undo(this, SLOT(undo()), actionCollection());
 	KStandardGameAction::redo(this, SLOT(redo()), actionCollection());
 
-	KAction * a = KStandardGameAction::hint(this, SLOT(giveHint()), actionCollection());
+	QAction * a = KStandardGameAction::hint(this, SLOT(giveHint()), actionCollection());
 	// The default value (H) conflicts with the keys assigned
 	// to add letter/numbers to the board.
-	shortcut = a->shortcut();
-	shortcut.setPrimary(QKeySequence(Qt::Key_F2));
-	a->setShortcut(shortcut);
+	actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::Key_F2));
 
 	KStandardGameAction::solve(this, SLOT(autoSolve()), actionCollection());
 
-	a = new KAction(this);
+	a = new QAction(this);
 	actionCollection()->addAction( QLatin1String( "move_dub_puzzle" ), a);
 	a->setText(i18n("Check"));
-	a->setIcon(KIcon( QLatin1String( "games-endturn" )));
-	connect(a, SIGNAL(triggered(bool)), SLOT(dubPuzzle()));
+	a->setIcon(QIcon::fromTheme( QLatin1String( "games-endturn" )));
+	connect(a, &QAction::triggered, this, &KSudoku::dubPuzzle);
 	addAction(a);
-
-	//WEB
-	a = new KAction(this);
-	actionCollection()->addAction( QLatin1String( "home_page" ), a);
-	a->setText(i18n("Home Page"));
-	a->setIcon(KIcon( QLatin1String( "internet-web-browser" )));
-	connect(a, SIGNAL(triggered(bool)), SLOT(homepage()));
 }
 
 void KSudoku::setupStatusBar (int difficulty, int symmetry)
@@ -533,8 +524,7 @@ void KSudoku::setupStatusBar (int difficulty, int symmetry)
 	// Set up a combo box for symmetry of puzzle layout.
 	statusBar()->addPermanentWidget (new QLabel (i18n("Symmetry")));
 	QComboBox * symmetryBox = new QComboBox (this);
-	QObject::connect(symmetryBox, SIGNAL(activated(int)),
-		    		this, SLOT(symmetryChanged(int)));
+	QObject::connect(symmetryBox, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &KSudoku::symmetryChanged);
 	symmetryBox->setToolTip(i18nc(
 		"Symmetry of layout of clues when puzzle starts", "Symmetry"));
 	symmetryBox->setWhatsThis(i18n(
@@ -616,35 +606,33 @@ void KSudoku::pop()
 // 	if(glwin) glwin->pop();
 }
 
-void KSudoku::dragEnterEvent(QDragEnterEvent */*event*/)
+void KSudoku::dragEnterEvent(QDragEnterEvent * event)
 {
     // accept uri drops only
-
-	//TODO PORT
-    //KUrl::List::fromMimeData( e->mimeData() )
-
-    //event->accept(KUrlDrag::canDecode(event));
+    if(event->mimeData()->hasUrls())
+        event->accept();
 }
 
 void KSudoku::dropEvent(QDropEvent *event)
 {
-	//TODO PORT
-   KUrl::List Urls = KUrl::List::fromMimeData( event->mimeData() );
-
-
-    if ( !Urls.isEmpty() )
+    const QMimeData * data = event->mimeData();
+    if(data->hasUrls())
     {
-        // okay, we have a URI.. process it
-        const KUrl &Url = Urls.first();
+        QList<QUrl> Urls = data->urls();
 
-		Game game = ksudoku::Serializer::load(Url, this);
-// 		if(game)
-// 			(new KSudoku(game))->show();
-		if(game.isValid())
-			startGame(game);
-// 		delete game;
+        if ( !Urls.isEmpty() )
+        {
+            // okay, we have a URI.. process it
+            const QUrl &Url = Urls.first();
+
+            QString errorMsg;
+            const Game game = ksudoku::Serializer::load(Url, this, errorMsg);
+            if(game.isValid())
+                startGame(game);
+            else
+                KMessageBox::error(this, errorMsg, i18n("Could not load game."));
+        }
     }
-
 }
 
 void KSudoku::gameNew()
@@ -674,13 +662,14 @@ void KSudoku::gameOpen()
 	// the Open shortcut is pressed (usually CTRL+O) or the Open toolbar
 	// button is clicked
 	// standard filedialog
-	KUrl Url = KFileDialog::getOpenUrl(KUrl("kfiledialog:///ksudoku"), QString(), this, i18n("Open Location"));
+	const QUrl Url = QFileDialog::getOpenFileUrl(this, i18n("Open Location"), QUrl::fromLocalFile(QDir::homePath()), QString());
 
 	if (!Url.isEmpty() && Url.isValid())
 	{
-		Game game = ksudoku::Serializer::load(Url, this);
+		QString errorMsg;
+		Game game = ksudoku::Serializer::load(Url, this, errorMsg);
 		if(!game.isValid()) {
-			KMessageBox::error(this, i18n("Could not load game."));
+			KMessageBox::error(this, errorMsg, i18n("Could not load game."));
 			return;
 		}
 
@@ -702,9 +691,13 @@ void KSudoku::gameSave()
 	Game game = currentGame();
 	if(!game.isValid()) return;
 
-	if(game.getUrl().isEmpty()) game.setUrl(KFileDialog::getSaveUrl(KUrl("kfiledialog:///ksudoku")));
- 	if (!game.getUrl().isEmpty() && game.getUrl().isValid())
-		ksudoku::Serializer::store(game, game.getUrl(), this);
+	if(game.getUrl().isEmpty()) game.setUrl(QFileDialog::getSaveFileUrl());
+	if (!game.getUrl().isEmpty() && game.getUrl().isValid())
+	{
+		QString errorMsg;
+		if (!ksudoku::Serializer::store(game, game.getUrl(), this, errorMsg))
+			KMessageBox::error(this, errorMsg, i18n("Error Writing File"));
+	}
 }
 
 void KSudoku::gameSaveAs()
@@ -713,7 +706,7 @@ void KSudoku::gameSaveAs()
 	Game game = currentGame();
 	if(!game.isValid()) return;
 
-	game.setUrl(KFileDialog::getSaveUrl(KUrl("kfiledialog:///ksudoku")));
+	game.setUrl(QFileDialog::getSaveFileUrl());
     if (!game.getUrl().isEmpty() && game.getUrl().isValid())
     	gameSave();
 }
@@ -765,8 +758,8 @@ void KSudoku::optionsPreferences()
 	dialog->addPage(gameConfig, i18nc("Game Section in Config", "Game"), "games-config-options");
 	dialog->addPage(new KGameThemeSelector(dialog, Settings::self(), KGameThemeSelector::NewStuffDisableDownload), i18n("Theme"), "games-config-theme");
 
-    dialog->setHelp(QString(),"ksudoku");
-	connect(dialog, SIGNAL(settingsChanged(QString)), SLOT(updateSettings()));
+    //QT5 dialog->setHelp(QString(),"ksudoku");
+	connect(dialog, &KConfigDialog::settingsChanged, this, &KSudoku::updateSettings);
 	dialog->show();
 }
 
@@ -786,7 +779,7 @@ void KSudoku::updateSettings() {
 
 void KSudoku::difficultyChanged (KGameDifficulty::standardLevel difficulty)
 {
-    qDebug() << "Set difficulty =" << difficulty;
+    qCDebug(KSudokuLog) << "Set difficulty =" << difficulty;
     int newDifficulty = VeryEasy;
     switch (difficulty) {
     case KGameDifficulty::VeryEasy:
@@ -804,14 +797,14 @@ void KSudoku::difficultyChanged (KGameDifficulty::standardLevel difficulty)
     default:
 	return;
     }
-    qDebug() << "Set new difficulty =" << newDifficulty;
+    qCDebug(KSudokuLog) << "Set new difficulty =" << newDifficulty;
     m_welcomeScreen->setDifficulty(newDifficulty);
     return;
 }
 
 void KSudoku::difficultyChanged (int difficulty)
 {
-    qDebug() << "Set custom difficulty =" << difficulty;
+    qCDebug(KSudokuLog) << "Set custom difficulty =" << difficulty;
     m_welcomeScreen->setDifficulty(difficulty);
     if (difficulty == Unlimited) {
 	KMessageBox::information (this,
@@ -825,7 +818,7 @@ void KSudoku::difficultyChanged (int difficulty)
 
 void KSudoku::symmetryChanged (int symmetry)
 {
-    qDebug() << "Set symmetry =" << symmetry;
+    qCDebug(KSudokuLog) << "Set symmetry =" << symmetry;
     m_welcomeScreen->setSymmetry(symmetry);
 }
 
@@ -854,45 +847,6 @@ ksudoku::KsView* KSudoku::currentView() const{
 	return m_gameUI;
 }
 
-void KSudoku::loadCustomShapeFromPath()
-{
-	KUrl Url = KFileDialog::getOpenUrl( KUrl(), QString(), this, i18n("Open Location") );
-
-	if ( Url.isEmpty() || !Url.isValid() )
-	{
-		//TODO ERROR
-		return;
-	}
-
-	QString tmpFile;
-	if(!KIO::NetAccess::download( Url, tmpFile, this ))
-	{
-		//TODO ERROR
-		return;
-	}
-
-	KStandardDirs myStdDir;
-	const QString destDir = myStdDir.saveLocation( "data", /*kapp->instanceName() + TODO PORT */"ksudoku/", true );
-	KStandardDirs::makeDir( destDir );
-
-	KTar archive( tmpFile );
-
-	if ( archive.open( QIODevice::ReadOnly ) )
-	{
-		const KArchiveDirectory *archiveDir = archive.directory();
-		archiveDir->copyTo( destDir );
-		archive.close();
-	}
-	else
-	{
-		//just copy
-		KIO::file_copy (Url, destDir);
-	}
-
-	KIO::NetAccess::removeTempFile(tmpFile);
-	updateShapesList();
-}
-
 void KSudoku::enableMessages()
 {
 	// Enable all messages that the user has marked "Do not show again".
@@ -900,7 +854,7 @@ void KSudoku::enableMessages()
 					i18n("Enable all messages"));
 	if (result == KMessageBox::Yes) {
 		KMessageBox::enableAllMessages();
-		KGlobal::config()->sync();	// Save the changes to disk.
+		KSharedConfig::openConfig()->sync();	// Save the changes to disk.
 	}
 }
 
@@ -918,9 +872,8 @@ bool KSudokuNewStuff::install( const QString &fileName )
 		return false;
 
 	const KArchiveDirectory *archiveDir = archive.directory();
-	KStandardDirs myStdDir;
-	const QString destDir = myStdDir.saveLocation("data", /*kapp->instanceName() + TODO PORT*/"ksudoku/", true);
-	KStandardDirs::makeDir(destDir);
+	const QString destDir = QStandardPaths::writableLocation( QStandardPaths::GenericDataLocation ) + QStringLiteral("/ksudoku/");
+	QDir().mkpath(destDir);
 
 	archiveDir->copyTo(destDir);
 	archive.close();
@@ -937,4 +890,4 @@ bool KSudokuNewStuff::createUploadFile( const QString &/*fileName*/ )
 
 
 
-#include "ksudoku.moc"
+
