@@ -24,7 +24,9 @@
 #ifndef _KSUDOKU_H_
 #define _KSUDOKU_H_
 
-#include <kxmlguiwindow.h>
+#include <QUrl>
+
+#include <KXmlGuiWindow>
 #if 0
 #include <knewstuff/knewstuff.h>
 #endif
@@ -32,7 +34,7 @@
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgamedifficulty.h>
 
-class KUrl;
+class QPrinter;
 
 namespace ksudoku {
 class KsView;
@@ -85,19 +87,18 @@ public:
      */
 	virtual ~KSudoku();
 	
-	void loadGame(const KUrl& url);
+	void loadGame(const QUrl& url);
 	
 public:
 	void updateShapesList();
-	void loadCustomShapeFromPath();
 	void createCustomShape();
 
 	ksudoku::Game    currentGame() const;
 	ksudoku::KsView* currentView() const;
 
 protected:
-	virtual void dragEnterEvent(QDragEnterEvent *event);
-	virtual void dropEvent(QDropEvent *event);
+	void dragEnterEvent(QDragEnterEvent *event) override;
+	void dropEvent(QDropEvent *event) override;
 
 public slots:
 	void onCompleted(bool isCorrect, const QTime& required, bool withHelp = false);
@@ -107,7 +108,7 @@ public slots:
 	void startGame(const ::ksudoku::Game& game);
 	void endCurrentGame();
 
-	bool queryClose();
+	bool queryClose() override;
 	
 private slots:
 	void difficultyChanged (KGameDifficulty::standardLevel difficulty);
@@ -137,9 +138,6 @@ private slots:
 //  void updateStatusBar();
 //  void changeStatusbar(const QString& text);
 
-	void homepage();
-
-
 	void onModified(bool isModified);
 
 	void enableMessages();
