@@ -32,7 +32,7 @@
 #endif
 
 #include <QtGlobal>
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 #include <OpenGL/gl.h>
 #include <OpenGL/glu.h>
 #elif defined(Q_WS_WIN)
